==> budget-rpc-0.3.0.15-sources.jar: com/chinayanghe/msp/budget/vo/front/transferplan/in/FissionTransferVo.java <==
package com.chinayanghe.msp.budget.vo.front.transferplan.in;

import com.chinayanghe.msp.budget.vo.in.BaseVo;
import com.chinayanghe.msp.budget.vo.out.BizResponseJson;

import java.io.Serializable;
import java.util.List;

/**
 * Created by yumemor on 2017/6/13.
 */
public class FissionTransferVo extends BaseVo implements Serializable {

    private String userId;
    private String userName;
    //预留单号
    private String fmkblnr;
    //uuid
    private String fissionCode;
    private List<Integer> oldProjectIds;
    private List<Integer> newProjectIds;

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public List<Integer> getOldProjectIds() {
        return oldProjectIds;
    }

    public void setOldProjectIds(List<Integer> oldProjectIds) {
        this.oldProjectIds = oldProjectIds;
    }

    public List<Integer> getNewProjectIds() {
        return newProjectIds;
    }

    public void setNewProjectIds(List<Integer> newProjectIds) {
        this.newProjectIds = newProjectIds;
    }

    public String getFmkblnr() {
        return fmkblnr;
    }

    public void setFmkblnr(String fmkblnr) {
        this.fmkblnr = fmkblnr;
    }

    public String getFissionCode() {
        return fissionCode;
    }

    public void setFissionCode(String fissionCode) {
        this.fissionCode = fissionCode;
    }

    @Override
    public BizResponseJson<?> validate() {
        return null;
    }
}

==> budget-rpc-0.3.0.24-sources.jar: com/chinayanghe/msp/budget/vo/front/transferplan/in/FissionTransferVo.java <==
package com.chinayanghe.msp.budget.vo.front.transferplan.in;

import com.chinayanghe.msp.budget.vo.in.BaseVo;
import com.chinayanghe.msp.budget.vo.out.BizResponseJson;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

/**
 * Created by yumemor on 2017/6/13.
 */
public class FissionTransferVo extends BaseVo implements Serializable {

    private Integer pushId;
    private String userId;
    private String userName;
    //uuid
    private String fissionCode;
    private List<Integer> oldProjectIds;
    private List<Integer> newProjectIds;

    private Map<Integer,Map<String,String>> fissionMap;

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public List<Integer> getOldProjectIds() {
        return oldProjectIds;
    }

    public void setOldProjectIds(List<Integer> oldProjectIds) {
        this.oldProjectIds = oldProjectIds;
    }

    public List<Integer> getNewProjectIds() {
        return newProjectIds;
    }

    public void setNewProjectIds(List<Integer> newProjectIds) {
        this.newProjectIds = newProjectIds;
    }
    public String getFissionCode() {
        return fissionCode;
    }

    public void setFissionCode(String fissionCode) {
        this.fissionCode = fissionCode;
    }

    @Override
    public BizResponseJson<?> validate() {
        return null;
    }

    public Integer getPushId() {
        return pushId;
    }

    public void setPushId(Integer pushId) {
        this.pushId = pushId;
    }

    public Map<Integer, Map<String, String>> getFissionMap() {
        return fissionMap;
    }

    public void setFissionMap(Map<Integer, Map<String, String>> fissionMap) {
        this.fissionMap = fissionMap;
    }
}
